# Lowest bid disqualified (R036)

The lowest submitted bid is disqualified, while the award criterion is price only.

## Methodology

A contracting process is flagged if:

- There are one or more active awards.
- There are one or more valid bids with amounts.
- The lowest submitted bid is disqualified.

:::{admonition} Example
:class: seealso

The Public Works Department sets the award criterion as lowest price. FairDeal Inc. submits a bid of \$100,000. BribeCorp submits a bid of \$111,111. The Public Works Department disqualifies the bid from FairDeal Inc.
:::

:::{admonition} Why is this a red flag?
:class: hint

A corrupt buyer can award the pre-determined bidder by disqualifying lower-priced bids.
:::

<small>Based on "The lowest bid is rejected almost inexplicably" in [*Fraud in Public Procurement: A collection of Red Flags and Best Practices*](https://ec.europa.eu/sfc/system/files/documents/sfc-files/fraud-public-procurement-final-20122017-ares20176254403.pdf), "Lowest bidder not selected" in [*Common Red Flags of Fraud and Corruption in Procurement*](https://web.archive.org/web/20200918183744/https://www.worldbank.org/en/about/unit/integrity-vice-presidency/brief/common-red-flags-of-fraud-and-corruption-in-procurement), and "Award to other than lowest qualified bidder" in [*Guide to Combating Corruption & Fraud in Infrastructure Development Projects*](https://guide.iacrc.org/red-flag-award-to-other-than-lowest-qualified-bidder/).</small>

## Output

The indicator's value is always 1.0.

## Configuration

The indicator is not configurable.

:::{seealso}
`no_price_comparison_procurement_methods` and `price_comparison_procurement_methods` in {ref}`global-configuration`
:::

## Exclusions

A contracting process is excluded if:

- Prices are predetermined by the buyer.

## Demonstration

*Input*

:::{literalinclude} ../../../examples/R/036.jsonl
:language: json
:::

*Output*

```console
$ ocdscardinal indicators --settings docs/examples/settings.ini --no-meta docs/examples/R/036.jsonl
{"OCID":{"F":{"R036":1.0}}}

```
